Class: EmassClient::CMMCAssessmentDashboardsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/emass_client/api/cmmc_assessment_dashboards_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ CMMCAssessmentDashboardsApi

Returns a new instance of CMMCAssessmentDashboardsApi.



19
20
21
# File 'lib/emass_client/api/cmmc_assessment_dashboards_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/emass_client/api/cmmc_assessment_dashboards_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#get_cmmc_assessment_requirement_objectives_details(org_id, opts = {}) ⇒ GetSystemStatusDetails200Response

CMMC Assessment Requirement Objectives Details Get CMMC assessment requirement objectives details dashboard information.

Parameters:

  • org_id (Integer)

    **Organization Id**: The unique organization identifier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :excludeinherited (Boolean)

    **Exclude Inherited**: If no value is specified, the default returns false to include inherited data. (default to false)

  • :page_index (Integer)

    **Page Index**: If no value is specified, the default returns results from the first page with an index of 0. (default to 0)

  • :page_size (Integer)

    **Page Size**: If no value is specified, the default returns 20000 per page. (default to 20000)

Returns:



30
31
32
33
# File 'lib/emass_client/api/cmmc_assessment_dashboards_api.rb', line 30

def get_cmmc_assessment_requirement_objectives_details(org_id, opts = {})
  data, _status_code, _headers = get_cmmc_assessment_requirement_objectives_details_with_http_info(org_id, opts)
  data
end

#get_cmmc_assessment_requirement_objectives_details_with_http_info(org_id, opts = {}) ⇒ Array<(GetSystemStatusDetails200Response, Integer, Hash)>

CMMC Assessment Requirement Objectives Details Get CMMC assessment requirement objectives details dashboard information.

Parameters:

  • org_id (Integer)

    **Organization Id**: The unique organization identifier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :excludeinherited (Boolean)

    **Exclude Inherited**: If no value is specified, the default returns false to include inherited data. (default to false)

  • :page_index (Integer)

    **Page Index**: If no value is specified, the default returns results from the first page with an index of 0. (default to 0)

  • :page_size (Integer)

    **Page Size**: If no value is specified, the default returns 20000 per page. (default to 20000)

Returns:



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/emass_client/api/cmmc_assessment_dashboards_api.rb', line 43

def get_cmmc_assessment_requirement_objectives_details_with_http_info(org_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CMMCAssessmentDashboardsApi.get_cmmc_assessment_requirement_objectives_details ...'
  end
  # verify the required parameter 'org_id' is set
  if @api_client.config.client_side_validation && org_id.nil?
    fail ArgumentError, "Missing the required parameter 'org_id' when calling CMMCAssessmentDashboardsApi.get_cmmc_assessment_requirement_objectives_details"
  end
  # resource path
  local_var_path = '/api/dashboards/cmmc-assessment-requirement-objectives-details'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'orgId'] = org_id
  query_params[:'excludeinherited'] = opts[:'excludeinherited'] if !opts[:'excludeinherited'].nil?
  query_params[:'pageIndex'] = opts[:'page_index'] if !opts[:'page_index'].nil?
  query_params[:'pageSize'] = opts[:'page_size'] if !opts[:'page_size'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetSystemStatusDetails200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['apiKey', 'mockType', 'userId']

  new_options = opts.merge(
    :operation => :"CMMCAssessmentDashboardsApi.get_cmmc_assessment_requirement_objectives_details",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CMMCAssessmentDashboardsApi#get_cmmc_assessment_requirement_objectives_details\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_cmmc_assessment_requirements_compliance_summary(org_id, opts = {}) ⇒ GetSystemStatusDetails200Response

CMMC Assessment Requirements Compliance Summary Get CMMC assessment requirements compliance summary dashboard information.

Parameters:

  • org_id (Integer)

    **Organization Id**: The unique organization identifier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :excludeinherited (Boolean)

    **Exclude Inherited**: If no value is specified, the default returns false to include inherited data. (default to false)

  • :page_index (Integer)

    **Page Index**: If no value is specified, the default returns results from the first page with an index of 0. (default to 0)

  • :page_size (Integer)

    **Page Size**: If no value is specified, the default returns 20000 per page. (default to 20000)

Returns:



103
104
105
106
# File 'lib/emass_client/api/cmmc_assessment_dashboards_api.rb', line 103

def get_cmmc_assessment_requirements_compliance_summary(org_id, opts = {})
  data, _status_code, _headers = get_cmmc_assessment_requirements_compliance_summary_with_http_info(org_id, opts)
  data
end

#get_cmmc_assessment_requirements_compliance_summary_with_http_info(org_id, opts = {}) ⇒ Array<(GetSystemStatusDetails200Response, Integer, Hash)>

CMMC Assessment Requirements Compliance Summary Get CMMC assessment requirements compliance summary dashboard information.

Parameters:

  • org_id (Integer)

    **Organization Id**: The unique organization identifier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :excludeinherited (Boolean)

    **Exclude Inherited**: If no value is specified, the default returns false to include inherited data. (default to false)

  • :page_index (Integer)

    **Page Index**: If no value is specified, the default returns results from the first page with an index of 0. (default to 0)

  • :page_size (Integer)

    **Page Size**: If no value is specified, the default returns 20000 per page. (default to 20000)

Returns:



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/emass_client/api/cmmc_assessment_dashboards_api.rb', line 116

def get_cmmc_assessment_requirements_compliance_summary_with_http_info(org_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CMMCAssessmentDashboardsApi.get_cmmc_assessment_requirements_compliance_summary ...'
  end
  # verify the required parameter 'org_id' is set
  if @api_client.config.client_side_validation && org_id.nil?
    fail ArgumentError, "Missing the required parameter 'org_id' when calling CMMCAssessmentDashboardsApi.get_cmmc_assessment_requirements_compliance_summary"
  end
  # resource path
  local_var_path = '/api/dashboards/cmmc-assessment-requirements-compliance-summary'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'orgId'] = org_id
  query_params[:'excludeinherited'] = opts[:'excludeinherited'] if !opts[:'excludeinherited'].nil?
  query_params[:'pageIndex'] = opts[:'page_index'] if !opts[:'page_index'].nil?
  query_params[:'pageSize'] = opts[:'page_size'] if !opts[:'page_size'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetSystemStatusDetails200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['apiKey', 'mockType', 'userId']

  new_options = opts.merge(
    :operation => :"CMMCAssessmentDashboardsApi.get_cmmc_assessment_requirements_compliance_summary",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CMMCAssessmentDashboardsApi#get_cmmc_assessment_requirements_compliance_summary\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_cmmc_assessment_security_requirements_details(org_id, opts = {}) ⇒ GetSystemStatusDetails200Response

CMMC Assessment Security Requirements Details Get CMMC assessment security requirements details dashboard information.

Parameters:

  • org_id (Integer)

    **Organization Id**: The unique organization identifier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :excludeinherited (Boolean)

    **Exclude Inherited**: If no value is specified, the default returns false to include inherited data. (default to false)

  • :page_index (Integer)

    **Page Index**: If no value is specified, the default returns results from the first page with an index of 0. (default to 0)

  • :page_size (Integer)

    **Page Size**: If no value is specified, the default returns 20000 per page. (default to 20000)

Returns:



176
177
178
179
# File 'lib/emass_client/api/cmmc_assessment_dashboards_api.rb', line 176

def get_cmmc_assessment_security_requirements_details(org_id, opts = {})
  data, _status_code, _headers = get_cmmc_assessment_security_requirements_details_with_http_info(org_id, opts)
  data
end

#get_cmmc_assessment_security_requirements_details_with_http_info(org_id, opts = {}) ⇒ Array<(GetSystemStatusDetails200Response, Integer, Hash)>

CMMC Assessment Security Requirements Details Get CMMC assessment security requirements details dashboard information.

Parameters:

  • org_id (Integer)

    **Organization Id**: The unique organization identifier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :excludeinherited (Boolean)

    **Exclude Inherited**: If no value is specified, the default returns false to include inherited data. (default to false)

  • :page_index (Integer)

    **Page Index**: If no value is specified, the default returns results from the first page with an index of 0. (default to 0)

  • :page_size (Integer)

    **Page Size**: If no value is specified, the default returns 20000 per page. (default to 20000)

Returns:



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/emass_client/api/cmmc_assessment_dashboards_api.rb', line 189

def get_cmmc_assessment_security_requirements_details_with_http_info(org_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CMMCAssessmentDashboardsApi.get_cmmc_assessment_security_requirements_details ...'
  end
  # verify the required parameter 'org_id' is set
  if @api_client.config.client_side_validation && org_id.nil?
    fail ArgumentError, "Missing the required parameter 'org_id' when calling CMMCAssessmentDashboardsApi.get_cmmc_assessment_security_requirements_details"
  end
  # resource path
  local_var_path = '/api/dashboards/cmmc-assessment-security-requirements-details'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'orgId'] = org_id
  query_params[:'excludeinherited'] = opts[:'excludeinherited'] if !opts[:'excludeinherited'].nil?
  query_params[:'pageIndex'] = opts[:'page_index'] if !opts[:'page_index'].nil?
  query_params[:'pageSize'] = opts[:'page_size'] if !opts[:'page_size'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetSystemStatusDetails200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['apiKey', 'mockType', 'userId']

  new_options = opts.merge(
    :operation => :"CMMCAssessmentDashboardsApi.get_cmmc_assessment_security_requirements_details",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CMMCAssessmentDashboardsApi#get_cmmc_assessment_security_requirements_details\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_cmmc_assessment_status_summary(org_id, opts = {}) ⇒ GetSystemStatusDetails200Response

CMMC Assessment Status Summary Get CMMC assessment status summary dashboard information.

Parameters:

  • org_id (Integer)

    **Organization Id**: The unique organization identifier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :excludeinherited (Boolean)

    **Exclude Inherited**: If no value is specified, the default returns false to include inherited data. (default to false)

  • :page_index (Integer)

    **Page Index**: If no value is specified, the default returns results from the first page with an index of 0. (default to 0)

  • :page_size (Integer)

    **Page Size**: If no value is specified, the default returns 20000 per page. (default to 20000)

Returns:



249
250
251
252
# File 'lib/emass_client/api/cmmc_assessment_dashboards_api.rb', line 249

def get_cmmc_assessment_status_summary(org_id, opts = {})
  data, _status_code, _headers = get_cmmc_assessment_status_summary_with_http_info(org_id, opts)
  data
end

#get_cmmc_assessment_status_summary_with_http_info(org_id, opts = {}) ⇒ Array<(GetSystemStatusDetails200Response, Integer, Hash)>

CMMC Assessment Status Summary Get CMMC assessment status summary dashboard information.

Parameters:

  • org_id (Integer)

    **Organization Id**: The unique organization identifier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :excludeinherited (Boolean)

    **Exclude Inherited**: If no value is specified, the default returns false to include inherited data. (default to false)

  • :page_index (Integer)

    **Page Index**: If no value is specified, the default returns results from the first page with an index of 0. (default to 0)

  • :page_size (Integer)

    **Page Size**: If no value is specified, the default returns 20000 per page. (default to 20000)

Returns:



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/emass_client/api/cmmc_assessment_dashboards_api.rb', line 262

def get_cmmc_assessment_status_summary_with_http_info(org_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CMMCAssessmentDashboardsApi.get_cmmc_assessment_status_summary ...'
  end
  # verify the required parameter 'org_id' is set
  if @api_client.config.client_side_validation && org_id.nil?
    fail ArgumentError, "Missing the required parameter 'org_id' when calling CMMCAssessmentDashboardsApi.get_cmmc_assessment_status_summary"
  end
  # resource path
  local_var_path = '/api/dashboards/cmmc-assessment-status-summary'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'orgId'] = org_id
  query_params[:'excludeinherited'] = opts[:'excludeinherited'] if !opts[:'excludeinherited'].nil?
  query_params[:'pageIndex'] = opts[:'page_index'] if !opts[:'page_index'].nil?
  query_params[:'pageSize'] = opts[:'page_size'] if !opts[:'page_size'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetSystemStatusDetails200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['apiKey', 'mockType', 'userId']

  new_options = opts.merge(
    :operation => :"CMMCAssessmentDashboardsApi.get_cmmc_assessment_status_summary",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CMMCAssessmentDashboardsApi#get_cmmc_assessment_status_summary\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end