Class: EmassClient::CmmcGet

Inherits:
Object
  • Object
show all
Defined in:
lib/emass_client/models/cmmc_get.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CmmcGet

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/emass_client/models/cmmc_get.rb', line 165

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `EmassClient::CmmcGet` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `EmassClient::CmmcGet`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'operation')
    self.operation = attributes[:'operation']
  end

  if attributes.key?(:'hq_organization_name')
    self.hq_organization_name = attributes[:'hq_organization_name']
  end

  if attributes.key?(:'uei')
    self.uei = attributes[:'uei']
  end

  if attributes.key?(:'osc_name')
    self.osc_name = attributes[:'osc_name']
  end

  if attributes.key?(:'highest_level_owner_cage_code')
    self.highest_level_owner_cage_code = attributes[:'highest_level_owner_cage_code']
  end

  if attributes.key?(:'cage_codes_in_scope')
    self.cage_codes_in_scope = attributes[:'cage_codes_in_scope']
  end

  if attributes.key?(:'number_of_employees')
    self.number_of_employees = attributes[:'number_of_employees']
  end

  if attributes.key?(:'scope')
    self.scope = attributes[:'scope']
  end

  if attributes.key?(:'scope_description')
    self.scope_description = attributes[:'scope_description']
  end

  if attributes.key?(:'assessment_standard')
    self.assessment_standard = attributes[:'assessment_standard']
  end

  if attributes.key?(:'assessment_id')
    self.assessment_id = attributes[:'assessment_id']
  end

  if attributes.key?(:'cmmc_uid')
    self.cmmc_uid = attributes[:'cmmc_uid']
  end

  if attributes.key?(:'overall_score')
    self.overall_score = attributes[:'overall_score']
  end

  if attributes.key?(:'cmmc_status')
    self.cmmc_status = attributes[:'cmmc_status']
  end

  if attributes.key?(:'cmmc_status_date')
    self.cmmc_status_date = attributes[:'cmmc_status_date']
  end

  if attributes.key?(:'cmmc_status_expiration_date')
    self.cmmc_status_expiration_date = attributes[:'cmmc_status_expiration_date']
  end
end

Instance Attribute Details

#assessment_idObject

Read-Only

Unique identifier for the assessment/certificate.



49
50
51
# File 'lib/emass_client/models/cmmc_get.rb', line 49

def assessment_id
  @assessment_id
end

#assessment_standardObject

Read-Only

Version of the CMMC Model used as part of the assessment.



46
47
48
# File 'lib/emass_client/models/cmmc_get.rb', line 46

def assessment_standard
  @assessment_standard
end

#cage_codes_in_scopeObject

Read-Only

The five position code(s) associated with the Organization Seeking Certification (OSC).



34
35
36
# File 'lib/emass_client/models/cmmc_get.rb', line 34

def cage_codes_in_scope
  @cage_codes_in_scope
end

#cmmc_statusObject

Read-Only

The status of the CMMC certification.



58
59
60
# File 'lib/emass_client/models/cmmc_get.rb', line 58

def cmmc_status
  @cmmc_status
end

#cmmc_status_dateObject

Read-Only

Date of the CMMC status.



61
62
63
# File 'lib/emass_client/models/cmmc_get.rb', line 61

def cmmc_status_date
  @cmmc_status_date
end

#cmmc_status_expiration_dateObject

Read-Only

Expiration date of the CMMC status.



64
65
66
# File 'lib/emass_client/models/cmmc_get.rb', line 64

def cmmc_status_expiration_date
  @cmmc_status_expiration_date
end

#cmmc_uidObject

Read-Only

Identifies the unique ID that is associated with a given CMMC certification for an organization.



52
53
54
# File 'lib/emass_client/models/cmmc_get.rb', line 52

def cmmc_uid
  @cmmc_uid
end

#highest_level_owner_cage_codeObject

Read-Only

Identifies the highest-level CAGE Code associated with a given organization.



31
32
33
# File 'lib/emass_client/models/cmmc_get.rb', line 31

def highest_level_owner_cage_code
  @highest_level_owner_cage_code
end

#hq_organization_nameObject

Read-Only

The name of the DIB Company.



22
23
24
# File 'lib/emass_client/models/cmmc_get.rb', line 22

def hq_organization_name
  @hq_organization_name
end

#number_of_employeesObject

Read-Only

The number of employees affiliated with the Organization Seeking Certification.



37
38
39
# File 'lib/emass_client/models/cmmc_get.rb', line 37

def number_of_employees
  @number_of_employees
end

#operationObject

Read-Only

Indicates the action that should be taken on the assessment record since the provided sinceDate.



19
20
21
# File 'lib/emass_client/models/cmmc_get.rb', line 19

def operation
  @operation
end

#osc_nameObject

Read-Only

The name of the Organization Seeking Certification.



28
29
30
# File 'lib/emass_client/models/cmmc_get.rb', line 28

def osc_name
  @osc_name
end

#overall_scoreObject

Read-Only

Identifies the overall calculated score for the assessment based on the assigned values to each applicable security requirement.



55
56
57
# File 'lib/emass_client/models/cmmc_get.rb', line 55

def overall_score
  @overall_score
end

#scopeObject

Read-Only

The scope of the OSC assessment.



40
41
42
# File 'lib/emass_client/models/cmmc_get.rb', line 40

def scope
  @scope
end

#scope_descriptionObject

Read-Only

Brief description of the scope of the OSC assessment



43
44
45
# File 'lib/emass_client/models/cmmc_get.rb', line 43

def scope_description
  @scope_description
end

#ueiObject

Read-Only

The Unique Entity Identifier assigned to the DIB Company.



25
26
27
# File 'lib/emass_client/models/cmmc_get.rb', line 25

def uei
  @uei
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
# File 'lib/emass_client/models/cmmc_get.rb', line 333

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = EmassClient.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



111
112
113
# File 'lib/emass_client/models/cmmc_get.rb', line 111

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



116
117
118
# File 'lib/emass_client/models/cmmc_get.rb', line 116

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/emass_client/models/cmmc_get.rb', line 89

def self.attribute_map
  {
    :'operation' => :'operation',
    :'hq_organization_name' => :'hqOrganizationName',
    :'uei' => :'uei',
    :'osc_name' => :'oscName',
    :'highest_level_owner_cage_code' => :'highestLevelOwnerCageCode',
    :'cage_codes_in_scope' => :'cageCodesInScope',
    :'number_of_employees' => :'numberOfEmployees',
    :'scope' => :'scope',
    :'scope_description' => :'scopeDescription',
    :'assessment_standard' => :'assessmentStandard',
    :'assessment_id' => :'assessmentId',
    :'cmmc_uid' => :'cmmcUid',
    :'overall_score' => :'overallScore',
    :'cmmc_status' => :'cmmcStatus',
    :'cmmc_status_date' => :'cmmcStatusDate',
    :'cmmc_status_expiration_date' => :'cmmcStatusExpirationDate'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/emass_client/models/cmmc_get.rb', line 309

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/emass_client/models/cmmc_get.rb', line 143

def self.openapi_nullable
  Set.new([
    :'operation',
    :'hq_organization_name',
    :'uei',
    :'osc_name',
    :'highest_level_owner_cage_code',
    :'cage_codes_in_scope',
    :'number_of_employees',
    :'scope',
    :'scope_description',
    :'assessment_standard',
    :'assessment_id',
    :'cmmc_uid',
    :'cmmc_status',
    :'cmmc_status_date',
    :'cmmc_status_expiration_date'
  ])
end

.openapi_typesObject

Attribute type mapping.



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/emass_client/models/cmmc_get.rb', line 121

def self.openapi_types
  {
    :'operation' => :'String',
    :'hq_organization_name' => :'String',
    :'uei' => :'String',
    :'osc_name' => :'String',
    :'highest_level_owner_cage_code' => :'String',
    :'cage_codes_in_scope' => :'String',
    :'number_of_employees' => :'Integer',
    :'scope' => :'String',
    :'scope_description' => :'String',
    :'assessment_standard' => :'String',
    :'assessment_id' => :'String',
    :'cmmc_uid' => :'String',
    :'overall_score' => :'Integer',
    :'cmmc_status' => :'String',
    :'cmmc_status_date' => :'Integer',
    :'cmmc_status_expiration_date' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/emass_client/models/cmmc_get.rb', line 273

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      operation == o.operation &&
      hq_organization_name == o.hq_organization_name &&
      uei == o.uei &&
      osc_name == o.osc_name &&
      highest_level_owner_cage_code == o.highest_level_owner_cage_code &&
      cage_codes_in_scope == o.cage_codes_in_scope &&
      number_of_employees == o.number_of_employees &&
      scope == o.scope &&
      scope_description == o.scope_description &&
      assessment_standard == o.assessment_standard &&
      assessment_id == o.assessment_id &&
      cmmc_uid == o.cmmc_uid &&
      overall_score == o.overall_score &&
      cmmc_status == o.cmmc_status &&
      cmmc_status_date == o.cmmc_status_date &&
      cmmc_status_expiration_date == o.cmmc_status_expiration_date
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



404
405
406
407
408
409
410
411
412
413
414
415
416
# File 'lib/emass_client/models/cmmc_get.rb', line 404

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


296
297
298
# File 'lib/emass_client/models/cmmc_get.rb', line 296

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



302
303
304
# File 'lib/emass_client/models/cmmc_get.rb', line 302

def hash
  [operation, hq_organization_name, uei, osc_name, highest_level_owner_cage_code, cage_codes_in_scope, number_of_employees, scope, scope_description, assessment_standard, assessment_id, cmmc_uid, overall_score, cmmc_status, cmmc_status_date, cmmc_status_expiration_date].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



246
247
248
249
250
# File 'lib/emass_client/models/cmmc_get.rb', line 246

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



380
381
382
# File 'lib/emass_client/models/cmmc_get.rb', line 380

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



386
387
388
389
390
391
392
393
394
395
396
397
398
# File 'lib/emass_client/models/cmmc_get.rb', line 386

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



374
375
376
# File 'lib/emass_client/models/cmmc_get.rb', line 374

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



254
255
256
257
258
259
# File 'lib/emass_client/models/cmmc_get.rb', line 254

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  operation_validator = EnumAttributeValidator.new('String', ["ADDED", "UPDATED", "DELETED", "unknown_default_open_api"])
  return false unless operation_validator.valid?(@operation)
  true
end