Class: EmassClient::ContainerScanResultsApi
- Inherits:
-
Object
- Object
- EmassClient::ContainerScanResultsApi
- Defined in:
- lib/emass_client/api/container_scan_results_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#add_container_sans_by_system_id(system_id, request_body, opts = {}) ⇒ ContainersResponsePost
Add one or many containers and their scan results Add containers and their scan results in the assets module for a system
systemId. -
#add_container_sans_by_system_id_with_http_info(system_id, request_body, opts = {}) ⇒ Array<(ContainersResponsePost, Integer, Hash)>
Add one or many containers and their scan results Add containers and their scan results in the assets module for a system `systemId`.
-
#delete_container_sans(system_id, container_resources_delete_body_inner, opts = {}) ⇒ ContainersResponseDelete
Remove one or many containers in a system Removes container scan resources and their scan results in the assets module for a system
systemId. -
#delete_container_sans_with_http_info(system_id, container_resources_delete_body_inner, opts = {}) ⇒ Array<(ContainersResponseDelete, Integer, Hash)>
Remove one or many containers in a system Removes container scan resources and their scan results in the assets module for a system `systemId`.
-
#initialize(api_client = ApiClient.default) ⇒ ContainerScanResultsApi
constructor
A new instance of ContainerScanResultsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ContainerScanResultsApi
Returns a new instance of ContainerScanResultsApi.
19 20 21 |
# File 'lib/emass_client/api/container_scan_results_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/emass_client/api/container_scan_results_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#add_container_sans_by_system_id(system_id, request_body, opts = {}) ⇒ ContainersResponsePost
Add one or many containers and their scan results Add containers and their scan results in the assets module for a system systemId. **Request Body Required Fields** - containerId - containerName - time - benchmarks (Object Array) - benchmark - results (Object Array) - ruleId - status - lastSeen **Example Request Body Required Fields** “‘ [ { "containerId": "container identification", "containerName": "container name", "time": Datetime of scan/result (1648217219), "benchmarks": [ { "benchmark": "RHEL_8_STIG", "results": [ { "ruleId": "rule identification", "status": [Pass,Fail,Other,Not Reviewed,Not Checked,Not Applicable], "lastSeen": Unix date format (1648217219) }, { "ruleId": "rule identification", "status": [Pass,Fail,Other,Not Reviewed,Not Checked,Not Applicable], "lastSeen": Unix date format (1648217219) } ] } ] } ] ““
28 29 30 31 |
# File 'lib/emass_client/api/container_scan_results_api.rb', line 28 def add_container_sans_by_system_id(system_id, request_body, opts = {}) data, _status_code, _headers = add_container_sans_by_system_id_with_http_info(system_id, request_body, opts) data end |
#add_container_sans_by_system_id_with_http_info(system_id, request_body, opts = {}) ⇒ Array<(ContainersResponsePost, Integer, Hash)>
Add one or many containers and their scan results Add containers and their scan results in the assets module for a system `systemId`. **Request Body Required Fields** - `containerId` - `containerName` - `time` - `benchmarks` (Object Array) - `benchmark` - `results` (Object Array) - `ruleId` - `status` - `lastSeen` **Example Request Body Required Fields** ``` [ { "containerId": "container identification", "containerName": "container name", "time": Datetime of scan/result (1648217219), "benchmarks": [ { "benchmark": "RHEL_8_STIG", "results": [ { "ruleId": "rule identification", "status": [Pass,Fail,Other,Not Reviewed,Not Checked,Not Applicable], "lastSeen": Unix date format (1648217219) }, { "ruleId": "rule identification", "status": [Pass,Fail,Other,Not Reviewed,Not Checked,Not Applicable], "lastSeen": Unix date format (1648217219) } ] } ] } ] ````
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/emass_client/api/container_scan_results_api.rb', line 39 def add_container_sans_by_system_id_with_http_info(system_id, request_body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContainerScanResultsApi.add_container_sans_by_system_id ...' end # verify the required parameter 'system_id' is set if @api_client.config.client_side_validation && system_id.nil? fail ArgumentError, "Missing the required parameter 'system_id' when calling ContainerScanResultsApi.add_container_sans_by_system_id" end # verify the required parameter 'request_body' is set if @api_client.config.client_side_validation && request_body.nil? fail ArgumentError, "Missing the required parameter 'request_body' when calling ContainerScanResultsApi.add_container_sans_by_system_id" end # resource path local_var_path = '/api/systems/{systemId}/container-scan-results'.sub('{' + 'systemId' + '}', CGI.escape(system_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(request_body) # return_type return_type = opts[:debug_return_type] || 'ContainersResponsePost' # auth_names auth_names = opts[:debug_auth_names] || ['apiKey', 'mockType', 'userId'] = opts.merge( :operation => :"ContainerScanResultsApi.add_container_sans_by_system_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContainerScanResultsApi#add_container_sans_by_system_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_container_sans(system_id, container_resources_delete_body_inner, opts = {}) ⇒ ContainersResponseDelete
Remove one or many containers in a system Removes container scan resources and their scan results in the assets module for a system systemId
102 103 104 105 |
# File 'lib/emass_client/api/container_scan_results_api.rb', line 102 def delete_container_sans(system_id, container_resources_delete_body_inner, opts = {}) data, _status_code, _headers = delete_container_sans_with_http_info(system_id, container_resources_delete_body_inner, opts) data end |
#delete_container_sans_with_http_info(system_id, container_resources_delete_body_inner, opts = {}) ⇒ Array<(ContainersResponseDelete, Integer, Hash)>
Remove one or many containers in a system Removes container scan resources and their scan results in the assets module for a system `systemId`
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/emass_client/api/container_scan_results_api.rb', line 113 def delete_container_sans_with_http_info(system_id, container_resources_delete_body_inner, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContainerScanResultsApi.delete_container_sans ...' end # verify the required parameter 'system_id' is set if @api_client.config.client_side_validation && system_id.nil? fail ArgumentError, "Missing the required parameter 'system_id' when calling ContainerScanResultsApi.delete_container_sans" end # verify the required parameter 'container_resources_delete_body_inner' is set if @api_client.config.client_side_validation && container_resources_delete_body_inner.nil? fail ArgumentError, "Missing the required parameter 'container_resources_delete_body_inner' when calling ContainerScanResultsApi.delete_container_sans" end # resource path local_var_path = '/api/systems/{systemId}/container-scan-results'.sub('{' + 'systemId' + '}', CGI.escape(system_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(container_resources_delete_body_inner) # return_type return_type = opts[:debug_return_type] || 'ContainersResponseDelete' # auth_names auth_names = opts[:debug_auth_names] || ['apiKey', 'mockType', 'userId'] = opts.merge( :operation => :"ContainerScanResultsApi.delete_container_sans", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContainerScanResultsApi#delete_container_sans\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |