Class: EmassClient::HwBaselineOptionalFields
- Inherits:
-
Object
- Object
- EmassClient::HwBaselineOptionalFields
- Defined in:
- lib/emass_client/models/hw_baseline_optional_fields.rb
Instance Attribute Summary collapse
-
#approval_status ⇒ Object
- Optional
-
Approval status of the hardware asset.
-
#asset_ip_address ⇒ Object
- Optional
-
IP address of the hardware asset.
-
#component_type ⇒ Object
- Optional
-
Type of the hardware asset.
-
#critical_asset ⇒ Object
- Optional
-
Indicates whether the asset is a critical information system asset.
-
#location ⇒ Object
- Optional
-
Location of the hardware asset.
-
#manufacturer ⇒ Object
- Optional
-
Manufacturer of the hardware asset.
-
#memory_size_type ⇒ Object
- Optional
-
Memory size / type of the hardware asset.
-
#model_number ⇒ Object
- Optional
-
Model number of the hardware asset.
-
#nickname ⇒ Object
- Optional
-
Nickname of the hardware asset.
-
#os_ios_fw_version ⇒ Object
- Optional
-
Operating System, IOS, or Firmware version of the hardware asset.
-
#public_facing ⇒ Object
- Optional
-
Public facing is defined as any asset that is accessible from a commercial connection.
-
#serial_number ⇒ Object
- Optional
-
Serial number of the hardware asset.
-
#virtual_asset ⇒ Object
- Optional
-
Determine if this is a virtual hardware asset.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HwBaselineOptionalFields
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ HwBaselineOptionalFields
Initializes the object
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 126 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `EmassClient::HwBaselineOptionalFields` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `EmassClient::HwBaselineOptionalFields`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'component_type') self.component_type = attributes[:'component_type'] end if attributes.key?(:'nickname') self.nickname = attributes[:'nickname'] end if attributes.key?(:'asset_ip_address') self.asset_ip_address = attributes[:'asset_ip_address'] end if attributes.key?(:'public_facing') self.public_facing = attributes[:'public_facing'] end if attributes.key?(:'virtual_asset') self.virtual_asset = attributes[:'virtual_asset'] end if attributes.key?(:'manufacturer') self.manufacturer = attributes[:'manufacturer'] end if attributes.key?(:'model_number') self.model_number = attributes[:'model_number'] end if attributes.key?(:'serial_number') self.serial_number = attributes[:'serial_number'] end if attributes.key?(:'os_ios_fw_version') self.os_ios_fw_version = attributes[:'os_ios_fw_version'] end if attributes.key?(:'memory_size_type') self.memory_size_type = attributes[:'memory_size_type'] end if attributes.key?(:'location') self.location = attributes[:'location'] end if attributes.key?(:'approval_status') self.approval_status = attributes[:'approval_status'] end if attributes.key?(:'critical_asset') self.critical_asset = attributes[:'critical_asset'] end end |
Instance Attribute Details
#approval_status ⇒ Object
- Optional
-
Approval status of the hardware asset.
52 53 54 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 52 def approval_status @approval_status end |
#asset_ip_address ⇒ Object
- Optional
-
IP address of the hardware asset.
25 26 27 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 25 def asset_ip_address @asset_ip_address end |
#component_type ⇒ Object
- Optional
-
Type of the hardware asset.
19 20 21 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 19 def component_type @component_type end |
#critical_asset ⇒ Object
- Optional
-
Indicates whether the asset is a critical information system asset.
55 56 57 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 55 def critical_asset @critical_asset end |
#location ⇒ Object
- Optional
-
Location of the hardware asset.
49 50 51 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 49 def location @location end |
#manufacturer ⇒ Object
- Optional
-
Manufacturer of the hardware asset. Populated with "Virtual" by default if Virtual Asset is true, however this can be overridden.
34 35 36 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 34 def manufacturer @manufacturer end |
#memory_size_type ⇒ Object
- Optional
-
Memory size / type of the hardware asset.
46 47 48 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 46 def memory_size_type @memory_size_type end |
#model_number ⇒ Object
- Optional
-
Model number of the hardware asset. Populated with "Virtual" by default if Virtual Asset is true, however this can be overridden
37 38 39 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 37 def model_number @model_number end |
#nickname ⇒ Object
- Optional
-
Nickname of the hardware asset.
22 23 24 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 22 def nickname @nickname end |
#os_ios_fw_version ⇒ Object
- Optional
-
Operating System, IOS, or Firmware version of the hardware asset.
43 44 45 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 43 def os_ios_fw_version @os_ios_fw_version end |
#public_facing ⇒ Object
- Optional
-
Public facing is defined as any asset that is accessible from a commercial connection.
28 29 30 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 28 def public_facing @public_facing end |
#serial_number ⇒ Object
- Optional
-
Serial number of the hardware asset. Populated with "Virtual" by default if Virtual Asset is true, however this can be overridden.
40 41 42 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 40 def serial_number @serial_number end |
#virtual_asset ⇒ Object
- Optional
-
Determine if this is a virtual hardware asset.
31 32 33 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 31 def virtual_asset @virtual_asset end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 267 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = EmassClient.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
77 78 79 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 77 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
82 83 84 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 82 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 58 def self.attribute_map { :'component_type' => :'componentType', :'nickname' => :'nickname', :'asset_ip_address' => :'assetIpAddress', :'public_facing' => :'publicFacing', :'virtual_asset' => :'virtualAsset', :'manufacturer' => :'manufacturer', :'model_number' => :'modelNumber', :'serial_number' => :'serialNumber', :'os_ios_fw_version' => :'OsIosFwVersion', :'memory_size_type' => :'memorySizeType', :'location' => :'location', :'approval_status' => :'approvalStatus', :'critical_asset' => :'criticalAsset' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 243 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 106 def self.openapi_nullable Set.new([ :'component_type', :'nickname', :'asset_ip_address', :'public_facing', :'virtual_asset', :'manufacturer', :'model_number', :'serial_number', :'os_ios_fw_version', :'memory_size_type', :'location', :'approval_status', :'critical_asset' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 87 def self.openapi_types { :'component_type' => :'String', :'nickname' => :'String', :'asset_ip_address' => :'String', :'public_facing' => :'Boolean', :'virtual_asset' => :'Boolean', :'manufacturer' => :'String', :'model_number' => :'String', :'serial_number' => :'String', :'os_ios_fw_version' => :'String', :'memory_size_type' => :'String', :'location' => :'String', :'approval_status' => :'String', :'critical_asset' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 210 def ==(o) return true if self.equal?(o) self.class == o.class && component_type == o.component_type && nickname == o.nickname && asset_ip_address == o.asset_ip_address && public_facing == o.public_facing && virtual_asset == o.virtual_asset && manufacturer == o.manufacturer && model_number == o.model_number && serial_number == o.serial_number && os_ios_fw_version == o.os_ios_fw_version && memory_size_type == o.memory_size_type && location == o.location && approval_status == o.approval_status && critical_asset == o.critical_asset end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
338 339 340 341 342 343 344 345 346 347 348 349 350 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 338 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
230 231 232 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 230 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
236 237 238 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 236 def hash [component_type, nickname, asset_ip_address, public_facing, virtual_asset, manufacturer, model_number, serial_number, os_ios_fw_version, memory_size_type, location, approval_status, critical_asset].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
195 196 197 198 199 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 195 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
314 315 316 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 314 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 320 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
308 309 310 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 308 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
203 204 205 206 |
# File 'lib/emass_client/models/hw_baseline_optional_fields.rb', line 203 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |