Class: EmassClient::UserSystemAssignmentsDashboardApi
- Inherits:
-
Object
- Object
- EmassClient::UserSystemAssignmentsDashboardApi
- Defined in:
- lib/emass_client/api/user_system_assignments_dashboard_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_user_system_assignments_details(org_id, opts = {}) ⇒ GetSystemStatusDetails200Response
User System Assignments Details Get user system assignments details dashboard information.
-
#get_user_system_assignments_details_with_http_info(org_id, opts = {}) ⇒ Array<(GetSystemStatusDetails200Response, Integer, Hash)>
User System Assignments Details Get user system assignments details dashboard information.
-
#initialize(api_client = ApiClient.default) ⇒ UserSystemAssignmentsDashboardApi
constructor
A new instance of UserSystemAssignmentsDashboardApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ UserSystemAssignmentsDashboardApi
Returns a new instance of UserSystemAssignmentsDashboardApi.
19 20 21 |
# File 'lib/emass_client/api/user_system_assignments_dashboard_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/emass_client/api/user_system_assignments_dashboard_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_user_system_assignments_details(org_id, opts = {}) ⇒ GetSystemStatusDetails200Response
User System Assignments Details Get user system assignments details dashboard information.
30 31 32 33 |
# File 'lib/emass_client/api/user_system_assignments_dashboard_api.rb', line 30 def get_user_system_assignments_details(org_id, opts = {}) data, _status_code, _headers = get_user_system_assignments_details_with_http_info(org_id, opts) data end |
#get_user_system_assignments_details_with_http_info(org_id, opts = {}) ⇒ Array<(GetSystemStatusDetails200Response, Integer, Hash)>
User System Assignments Details Get user system assignments details dashboard information.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/emass_client/api/user_system_assignments_dashboard_api.rb', line 43 def get_user_system_assignments_details_with_http_info(org_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UserSystemAssignmentsDashboardApi.get_user_system_assignments_details ...' end # verify the required parameter 'org_id' is set if @api_client.config.client_side_validation && org_id.nil? fail ArgumentError, "Missing the required parameter 'org_id' when calling UserSystemAssignmentsDashboardApi.get_user_system_assignments_details" end # resource path local_var_path = '/api/dashboards/user-system-assignments-details' # query parameters query_params = opts[:query_params] || {} query_params[:'orgId'] = org_id query_params[:'excludeinherited'] = opts[:'excludeinherited'] if !opts[:'excludeinherited'].nil? query_params[:'pageIndex'] = opts[:'page_index'] if !opts[:'page_index'].nil? query_params[:'pageSize'] = opts[:'page_size'] if !opts[:'page_size'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetSystemStatusDetails200Response' # auth_names auth_names = opts[:debug_auth_names] || ['apiKey', 'mockType', 'userId'] = opts.merge( :operation => :"UserSystemAssignmentsDashboardApi.get_user_system_assignments_details", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UserSystemAssignmentsDashboardApi#get_user_system_assignments_details\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |