Class: EmassClient::VASystemDashboardsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/emass_client/api/va_system_dashboards_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ VASystemDashboardsApi

Returns a new instance of VASystemDashboardsApi.



19
20
21
# File 'lib/emass_client/api/va_system_dashboards_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/emass_client/api/va_system_dashboards_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#get_va_system_a2_summary(org_id, opts = {}) ⇒ GetSystemStatusDetails200Response

VA System A2.0 Summary Get VA system A2.0 summary dashboard information.

Parameters:

  • org_id (Integer)

    **Organization Id**: The unique organization identifier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :excludeinherited (Boolean)

    **Exclude Inherited**: If no value is specified, the default returns false to include inherited data. (default to false)

  • :page_index (Integer)

    **Page Index**: If no value is specified, the default returns results from the first page with an index of 0. (default to 0)

  • :page_size (Integer)

    **Page Size**: If no value is specified, the default returns 20000 per page. (default to 20000)

Returns:



30
31
32
33
# File 'lib/emass_client/api/va_system_dashboards_api.rb', line 30

def get_va_system_a2_summary(org_id, opts = {})
  data, _status_code, _headers = get_va_system_a2_summary_with_http_info(org_id, opts)
  data
end

#get_va_system_a2_summary_with_http_info(org_id, opts = {}) ⇒ Array<(GetSystemStatusDetails200Response, Integer, Hash)>

VA System A2.0 Summary Get VA system A2.0 summary dashboard information.

Parameters:

  • org_id (Integer)

    **Organization Id**: The unique organization identifier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :excludeinherited (Boolean)

    **Exclude Inherited**: If no value is specified, the default returns false to include inherited data. (default to false)

  • :page_index (Integer)

    **Page Index**: If no value is specified, the default returns results from the first page with an index of 0. (default to 0)

  • :page_size (Integer)

    **Page Size**: If no value is specified, the default returns 20000 per page. (default to 20000)

Returns:



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/emass_client/api/va_system_dashboards_api.rb', line 43

def get_va_system_a2_summary_with_http_info(org_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: VASystemDashboardsApi.get_va_system_a2_summary ...'
  end
  # verify the required parameter 'org_id' is set
  if @api_client.config.client_side_validation && org_id.nil?
    fail ArgumentError, "Missing the required parameter 'org_id' when calling VASystemDashboardsApi.get_va_system_a2_summary"
  end
  # resource path
  local_var_path = '/api/dashboards/va-system-a2-summary'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'orgId'] = org_id
  query_params[:'excludeinherited'] = opts[:'excludeinherited'] if !opts[:'excludeinherited'].nil?
  query_params[:'pageIndex'] = opts[:'page_index'] if !opts[:'page_index'].nil?
  query_params[:'pageSize'] = opts[:'page_size'] if !opts[:'page_size'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetSystemStatusDetails200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['apiKey', 'mockType', 'userId']

  new_options = opts.merge(
    :operation => :"VASystemDashboardsApi.get_va_system_a2_summary",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: VASystemDashboardsApi#get_va_system_a2_summary\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_va_system_aa_summary(org_id, opts = {}) ⇒ GetSystemStatusDetails200Response

VA System A&A Summary Get VA system A&A summary dashboard information.

Parameters:

  • org_id (Integer)

    **Organization Id**: The unique organization identifier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :excludeinherited (Boolean)

    **Exclude Inherited**: If no value is specified, the default returns false to include inherited data. (default to false)

  • :page_index (Integer)

    **Page Index**: If no value is specified, the default returns results from the first page with an index of 0. (default to 0)

  • :page_size (Integer)

    **Page Size**: If no value is specified, the default returns 20000 per page. (default to 20000)

Returns:



103
104
105
106
# File 'lib/emass_client/api/va_system_dashboards_api.rb', line 103

def get_va_system_aa_summary(org_id, opts = {})
  data, _status_code, _headers = get_va_system_aa_summary_with_http_info(org_id, opts)
  data
end

#get_va_system_aa_summary_with_http_info(org_id, opts = {}) ⇒ Array<(GetSystemStatusDetails200Response, Integer, Hash)>

VA System A&amp;A Summary Get VA system A&amp;A summary dashboard information.

Parameters:

  • org_id (Integer)

    **Organization Id**: The unique organization identifier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :excludeinherited (Boolean)

    **Exclude Inherited**: If no value is specified, the default returns false to include inherited data. (default to false)

  • :page_index (Integer)

    **Page Index**: If no value is specified, the default returns results from the first page with an index of 0. (default to 0)

  • :page_size (Integer)

    **Page Size**: If no value is specified, the default returns 20000 per page. (default to 20000)

Returns:



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/emass_client/api/va_system_dashboards_api.rb', line 116

def get_va_system_aa_summary_with_http_info(org_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: VASystemDashboardsApi.get_va_system_aa_summary ...'
  end
  # verify the required parameter 'org_id' is set
  if @api_client.config.client_side_validation && org_id.nil?
    fail ArgumentError, "Missing the required parameter 'org_id' when calling VASystemDashboardsApi.get_va_system_aa_summary"
  end
  # resource path
  local_var_path = '/api/dashboards/va-system-aa-summary'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'orgId'] = org_id
  query_params[:'excludeinherited'] = opts[:'excludeinherited'] if !opts[:'excludeinherited'].nil?
  query_params[:'pageIndex'] = opts[:'page_index'] if !opts[:'page_index'].nil?
  query_params[:'pageSize'] = opts[:'page_size'] if !opts[:'page_size'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetSystemStatusDetails200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['apiKey', 'mockType', 'userId']

  new_options = opts.merge(
    :operation => :"VASystemDashboardsApi.get_va_system_aa_summary",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: VASystemDashboardsApi#get_va_system_aa_summary\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_va_system_fisma_invetory_crypto_summary(org_id, opts = {}) ⇒ GetSystemStatusDetails200Response

VA System FISMA Inventory Crypto Summary Get VA system FISMA inventory crypto summary dashboard information.

Parameters:

  • org_id (Integer)

    **Organization Id**: The unique organization identifier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :excludeinherited (Boolean)

    **Exclude Inherited**: If no value is specified, the default returns false to include inherited data. (default to false)

  • :page_index (Integer)

    **Page Index**: If no value is specified, the default returns results from the first page with an index of 0. (default to 0)

  • :page_size (Integer)

    **Page Size**: If no value is specified, the default returns 20000 per page. (default to 20000)

Returns:



176
177
178
179
# File 'lib/emass_client/api/va_system_dashboards_api.rb', line 176

def get_va_system_fisma_invetory_crypto_summary(org_id, opts = {})
  data, _status_code, _headers = get_va_system_fisma_invetory_crypto_summary_with_http_info(org_id, opts)
  data
end

#get_va_system_fisma_invetory_crypto_summary_with_http_info(org_id, opts = {}) ⇒ Array<(GetSystemStatusDetails200Response, Integer, Hash)>

VA System FISMA Inventory Crypto Summary Get VA system FISMA inventory crypto summary dashboard information.

Parameters:

  • org_id (Integer)

    **Organization Id**: The unique organization identifier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :excludeinherited (Boolean)

    **Exclude Inherited**: If no value is specified, the default returns false to include inherited data. (default to false)

  • :page_index (Integer)

    **Page Index**: If no value is specified, the default returns results from the first page with an index of 0. (default to 0)

  • :page_size (Integer)

    **Page Size**: If no value is specified, the default returns 20000 per page. (default to 20000)

Returns:



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/emass_client/api/va_system_dashboards_api.rb', line 189

def get_va_system_fisma_invetory_crypto_summary_with_http_info(org_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: VASystemDashboardsApi.get_va_system_fisma_invetory_crypto_summary ...'
  end
  # verify the required parameter 'org_id' is set
  if @api_client.config.client_side_validation && org_id.nil?
    fail ArgumentError, "Missing the required parameter 'org_id' when calling VASystemDashboardsApi.get_va_system_fisma_invetory_crypto_summary"
  end
  # resource path
  local_var_path = '/api/dashboards/va-system-fisma-inventory-crypto-summary'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'orgId'] = org_id
  query_params[:'excludeinherited'] = opts[:'excludeinherited'] if !opts[:'excludeinherited'].nil?
  query_params[:'pageIndex'] = opts[:'page_index'] if !opts[:'page_index'].nil?
  query_params[:'pageSize'] = opts[:'page_size'] if !opts[:'page_size'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetSystemStatusDetails200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['apiKey', 'mockType', 'userId']

  new_options = opts.merge(
    :operation => :"VASystemDashboardsApi.get_va_system_fisma_invetory_crypto_summary",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: VASystemDashboardsApi#get_va_system_fisma_invetory_crypto_summary\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_va_system_fisma_invetory_summary(org_id, opts = {}) ⇒ GetSystemStatusDetails200Response

VA System FISMA Inventory Summary Get VA system FISMA inventory summary dashboard information.

Parameters:

  • org_id (Integer)

    **Organization Id**: The unique organization identifier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :excludeinherited (Boolean)

    **Exclude Inherited**: If no value is specified, the default returns false to include inherited data. (default to false)

  • :page_index (Integer)

    **Page Index**: If no value is specified, the default returns results from the first page with an index of 0. (default to 0)

  • :page_size (Integer)

    **Page Size**: If no value is specified, the default returns 20000 per page. (default to 20000)

Returns:



249
250
251
252
# File 'lib/emass_client/api/va_system_dashboards_api.rb', line 249

def get_va_system_fisma_invetory_summary(org_id, opts = {})
  data, _status_code, _headers = get_va_system_fisma_invetory_summary_with_http_info(org_id, opts)
  data
end

#get_va_system_fisma_invetory_summary_with_http_info(org_id, opts = {}) ⇒ Array<(GetSystemStatusDetails200Response, Integer, Hash)>

VA System FISMA Inventory Summary Get VA system FISMA inventory summary dashboard information.

Parameters:

  • org_id (Integer)

    **Organization Id**: The unique organization identifier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :excludeinherited (Boolean)

    **Exclude Inherited**: If no value is specified, the default returns false to include inherited data. (default to false)

  • :page_index (Integer)

    **Page Index**: If no value is specified, the default returns results from the first page with an index of 0. (default to 0)

  • :page_size (Integer)

    **Page Size**: If no value is specified, the default returns 20000 per page. (default to 20000)

Returns:



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/emass_client/api/va_system_dashboards_api.rb', line 262

def get_va_system_fisma_invetory_summary_with_http_info(org_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: VASystemDashboardsApi.get_va_system_fisma_invetory_summary ...'
  end
  # verify the required parameter 'org_id' is set
  if @api_client.config.client_side_validation && org_id.nil?
    fail ArgumentError, "Missing the required parameter 'org_id' when calling VASystemDashboardsApi.get_va_system_fisma_invetory_summary"
  end
  # resource path
  local_var_path = '/api/dashboards/va-system-fisma-inventory-summary'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'orgId'] = org_id
  query_params[:'excludeinherited'] = opts[:'excludeinherited'] if !opts[:'excludeinherited'].nil?
  query_params[:'pageIndex'] = opts[:'page_index'] if !opts[:'page_index'].nil?
  query_params[:'pageSize'] = opts[:'page_size'] if !opts[:'page_size'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetSystemStatusDetails200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['apiKey', 'mockType', 'userId']

  new_options = opts.merge(
    :operation => :"VASystemDashboardsApi.get_va_system_fisma_invetory_summary",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: VASystemDashboardsApi#get_va_system_fisma_invetory_summary\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_va_system_icamp_tableau_poam_details(org_id, opts = {}) ⇒ GetSystemStatusDetails200Response

VA System ICAMP Tableau POAM Details Get VA system ICAMP Tableau POAM details dashboard information.

Parameters:

  • org_id (Integer)

    **Organization Id**: The unique organization identifier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :excludeinherited (Boolean)

    **Exclude Inherited**: If no value is specified, the default returns false to include inherited data. (default to false)

  • :page_index (Integer)

    **Page Index**: If no value is specified, the default returns results from the first page with an index of 0. (default to 0)

  • :page_size (Integer)

    **Page Size**: If no value is specified, the default returns 20000 per page. (default to 20000)

Returns:



322
323
324
325
# File 'lib/emass_client/api/va_system_dashboards_api.rb', line 322

def get_va_system_icamp_tableau_poam_details(org_id, opts = {})
  data, _status_code, _headers = get_va_system_icamp_tableau_poam_details_with_http_info(org_id, opts)
  data
end

#get_va_system_icamp_tableau_poam_details_with_http_info(org_id, opts = {}) ⇒ Array<(GetSystemStatusDetails200Response, Integer, Hash)>

VA System ICAMP Tableau POAM Details Get VA system ICAMP Tableau POAM details dashboard information.

Parameters:

  • org_id (Integer)

    **Organization Id**: The unique organization identifier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :excludeinherited (Boolean)

    **Exclude Inherited**: If no value is specified, the default returns false to include inherited data. (default to false)

  • :page_index (Integer)

    **Page Index**: If no value is specified, the default returns results from the first page with an index of 0. (default to 0)

  • :page_size (Integer)

    **Page Size**: If no value is specified, the default returns 20000 per page. (default to 20000)

Returns:



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
# File 'lib/emass_client/api/va_system_dashboards_api.rb', line 335

def get_va_system_icamp_tableau_poam_details_with_http_info(org_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: VASystemDashboardsApi.get_va_system_icamp_tableau_poam_details ...'
  end
  # verify the required parameter 'org_id' is set
  if @api_client.config.client_side_validation && org_id.nil?
    fail ArgumentError, "Missing the required parameter 'org_id' when calling VASystemDashboardsApi.get_va_system_icamp_tableau_poam_details"
  end
  # resource path
  local_var_path = '/api/dashboards/va-system-icamp-tableau-poam-details'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'orgId'] = org_id
  query_params[:'excludeinherited'] = opts[:'excludeinherited'] if !opts[:'excludeinherited'].nil?
  query_params[:'pageIndex'] = opts[:'page_index'] if !opts[:'page_index'].nil?
  query_params[:'pageSize'] = opts[:'page_size'] if !opts[:'page_size'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetSystemStatusDetails200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['apiKey', 'mockType', 'userId']

  new_options = opts.merge(
    :operation => :"VASystemDashboardsApi.get_va_system_icamp_tableau_poam_details",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: VASystemDashboardsApi#get_va_system_icamp_tableau_poam_details\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_va_system_pl109_reporting_summary(org_id, opts = {}) ⇒ GetSystemStatusDetails200Response

VA System P.L. 109 Reporting Summary Get VA system P.L. 109 reporting summary dashboard information.

Parameters:

  • org_id (Integer)

    **Organization Id**: The unique organization identifier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :excludeinherited (Boolean)

    **Exclude Inherited**: If no value is specified, the default returns false to include inherited data. (default to false)

  • :page_index (Integer)

    **Page Index**: If no value is specified, the default returns results from the first page with an index of 0. (default to 0)

  • :page_size (Integer)

    **Page Size**: If no value is specified, the default returns 20000 per page. (default to 20000)

Returns:



395
396
397
398
# File 'lib/emass_client/api/va_system_dashboards_api.rb', line 395

def get_va_system_pl109_reporting_summary(org_id, opts = {})
  data, _status_code, _headers = get_va_system_pl109_reporting_summary_with_http_info(org_id, opts)
  data
end

#get_va_system_pl109_reporting_summary_with_http_info(org_id, opts = {}) ⇒ Array<(GetSystemStatusDetails200Response, Integer, Hash)>

VA System P.L. 109 Reporting Summary Get VA system P.L. 109 reporting summary dashboard information.

Parameters:

  • org_id (Integer)

    **Organization Id**: The unique organization identifier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :excludeinherited (Boolean)

    **Exclude Inherited**: If no value is specified, the default returns false to include inherited data. (default to false)

  • :page_index (Integer)

    **Page Index**: If no value is specified, the default returns results from the first page with an index of 0. (default to 0)

  • :page_size (Integer)

    **Page Size**: If no value is specified, the default returns 20000 per page. (default to 20000)

Returns:



408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'lib/emass_client/api/va_system_dashboards_api.rb', line 408

def get_va_system_pl109_reporting_summary_with_http_info(org_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: VASystemDashboardsApi.get_va_system_pl109_reporting_summary ...'
  end
  # verify the required parameter 'org_id' is set
  if @api_client.config.client_side_validation && org_id.nil?
    fail ArgumentError, "Missing the required parameter 'org_id' when calling VASystemDashboardsApi.get_va_system_pl109_reporting_summary"
  end
  # resource path
  local_var_path = '/api/dashboards/va-system-pl-109-reporting-summary'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'orgId'] = org_id
  query_params[:'excludeinherited'] = opts[:'excludeinherited'] if !opts[:'excludeinherited'].nil?
  query_params[:'pageIndex'] = opts[:'page_index'] if !opts[:'page_index'].nil?
  query_params[:'pageSize'] = opts[:'page_size'] if !opts[:'page_size'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetSystemStatusDetails200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['apiKey', 'mockType', 'userId']

  new_options = opts.merge(
    :operation => :"VASystemDashboardsApi.get_va_system_pl109_reporting_summary",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: VASystemDashboardsApi#get_va_system_pl109_reporting_summary\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_va_system_threat_architecture_details(org_id, opts = {}) ⇒ GetSystemStatusDetails200Response

VA System Threat Architecture Details Get VA system threat architecture details dashboard information.

Parameters:

  • org_id (Integer)

    **Organization Id**: The unique organization identifier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :excludeinherited (Boolean)

    **Exclude Inherited**: If no value is specified, the default returns false to include inherited data. (default to false)

  • :page_index (Integer)

    **Page Index**: If no value is specified, the default returns results from the first page with an index of 0. (default to 0)

  • :page_size (Integer)

    **Page Size**: If no value is specified, the default returns 20000 per page. (default to 20000)

Returns:



468
469
470
471
# File 'lib/emass_client/api/va_system_dashboards_api.rb', line 468

def get_va_system_threat_architecture_details(org_id, opts = {})
  data, _status_code, _headers = get_va_system_threat_architecture_details_with_http_info(org_id, opts)
  data
end

#get_va_system_threat_architecture_details_with_http_info(org_id, opts = {}) ⇒ Array<(GetSystemStatusDetails200Response, Integer, Hash)>

VA System Threat Architecture Details Get VA system threat architecture details dashboard information.

Parameters:

  • org_id (Integer)

    **Organization Id**: The unique organization identifier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :excludeinherited (Boolean)

    **Exclude Inherited**: If no value is specified, the default returns false to include inherited data. (default to false)

  • :page_index (Integer)

    **Page Index**: If no value is specified, the default returns results from the first page with an index of 0. (default to 0)

  • :page_size (Integer)

    **Page Size**: If no value is specified, the default returns 20000 per page. (default to 20000)

Returns:



481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
# File 'lib/emass_client/api/va_system_dashboards_api.rb', line 481

def get_va_system_threat_architecture_details_with_http_info(org_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: VASystemDashboardsApi.get_va_system_threat_architecture_details ...'
  end
  # verify the required parameter 'org_id' is set
  if @api_client.config.client_side_validation && org_id.nil?
    fail ArgumentError, "Missing the required parameter 'org_id' when calling VASystemDashboardsApi.get_va_system_threat_architecture_details"
  end
  # resource path
  local_var_path = '/api/dashboards/va-system-threat-architecture-details'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'orgId'] = org_id
  query_params[:'excludeinherited'] = opts[:'excludeinherited'] if !opts[:'excludeinherited'].nil?
  query_params[:'pageIndex'] = opts[:'page_index'] if !opts[:'page_index'].nil?
  query_params[:'pageSize'] = opts[:'page_size'] if !opts[:'page_size'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetSystemStatusDetails200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['apiKey', 'mockType', 'userId']

  new_options = opts.merge(
    :operation => :"VASystemDashboardsApi.get_va_system_threat_architecture_details",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: VASystemDashboardsApi#get_va_system_threat_architecture_details\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_va_system_threat_risk_summary(org_id, opts = {}) ⇒ GetSystemStatusDetails200Response

VA System Threat Risks Summary Get VA system threat risk summary dashboard information.

Parameters:

  • org_id (Integer)

    **Organization Id**: The unique organization identifier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :excludeinherited (Boolean)

    **Exclude Inherited**: If no value is specified, the default returns false to include inherited data. (default to false)

  • :page_index (Integer)

    **Page Index**: If no value is specified, the default returns results from the first page with an index of 0. (default to 0)

  • :page_size (Integer)

    **Page Size**: If no value is specified, the default returns 20000 per page. (default to 20000)

Returns:



541
542
543
544
# File 'lib/emass_client/api/va_system_dashboards_api.rb', line 541

def get_va_system_threat_risk_summary(org_id, opts = {})
  data, _status_code, _headers = get_va_system_threat_risk_summary_with_http_info(org_id, opts)
  data
end

#get_va_system_threat_risk_summary_with_http_info(org_id, opts = {}) ⇒ Array<(GetSystemStatusDetails200Response, Integer, Hash)>

VA System Threat Risks Summary Get VA system threat risk summary dashboard information.

Parameters:

  • org_id (Integer)

    **Organization Id**: The unique organization identifier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :excludeinherited (Boolean)

    **Exclude Inherited**: If no value is specified, the default returns false to include inherited data. (default to false)

  • :page_index (Integer)

    **Page Index**: If no value is specified, the default returns results from the first page with an index of 0. (default to 0)

  • :page_size (Integer)

    **Page Size**: If no value is specified, the default returns 20000 per page. (default to 20000)

Returns:



554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
# File 'lib/emass_client/api/va_system_dashboards_api.rb', line 554

def get_va_system_threat_risk_summary_with_http_info(org_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: VASystemDashboardsApi.get_va_system_threat_risk_summary ...'
  end
  # verify the required parameter 'org_id' is set
  if @api_client.config.client_side_validation && org_id.nil?
    fail ArgumentError, "Missing the required parameter 'org_id' when calling VASystemDashboardsApi.get_va_system_threat_risk_summary"
  end
  # resource path
  local_var_path = '/api/dashboards/va-system-threat-risks-summary'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'orgId'] = org_id
  query_params[:'excludeinherited'] = opts[:'excludeinherited'] if !opts[:'excludeinherited'].nil?
  query_params[:'pageIndex'] = opts[:'page_index'] if !opts[:'page_index'].nil?
  query_params[:'pageSize'] = opts[:'page_size'] if !opts[:'page_size'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetSystemStatusDetails200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['apiKey', 'mockType', 'userId']

  new_options = opts.merge(
    :operation => :"VASystemDashboardsApi.get_va_system_threat_risk_summary",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: VASystemDashboardsApi#get_va_system_threat_risk_summary\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_va_system_threat_source_details(org_id, opts = {}) ⇒ GetSystemStatusDetails200Response

VA System Threat Sources Details Get VA system threat source details dashboard information.

Parameters:

  • org_id (Integer)

    **Organization Id**: The unique organization identifier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :excludeinherited (Boolean)

    **Exclude Inherited**: If no value is specified, the default returns false to include inherited data. (default to false)

  • :page_index (Integer)

    **Page Index**: If no value is specified, the default returns results from the first page with an index of 0. (default to 0)

  • :page_size (Integer)

    **Page Size**: If no value is specified, the default returns 20000 per page. (default to 20000)

Returns:



614
615
616
617
# File 'lib/emass_client/api/va_system_dashboards_api.rb', line 614

def get_va_system_threat_source_details(org_id, opts = {})
  data, _status_code, _headers = get_va_system_threat_source_details_with_http_info(org_id, opts)
  data
end

#get_va_system_threat_source_details_with_http_info(org_id, opts = {}) ⇒ Array<(GetSystemStatusDetails200Response, Integer, Hash)>

VA System Threat Sources Details Get VA system threat source details dashboard information.

Parameters:

  • org_id (Integer)

    **Organization Id**: The unique organization identifier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :excludeinherited (Boolean)

    **Exclude Inherited**: If no value is specified, the default returns false to include inherited data. (default to false)

  • :page_index (Integer)

    **Page Index**: If no value is specified, the default returns results from the first page with an index of 0. (default to 0)

  • :page_size (Integer)

    **Page Size**: If no value is specified, the default returns 20000 per page. (default to 20000)

Returns:



627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
# File 'lib/emass_client/api/va_system_dashboards_api.rb', line 627

def get_va_system_threat_source_details_with_http_info(org_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: VASystemDashboardsApi.get_va_system_threat_source_details ...'
  end
  # verify the required parameter 'org_id' is set
  if @api_client.config.client_side_validation && org_id.nil?
    fail ArgumentError, "Missing the required parameter 'org_id' when calling VASystemDashboardsApi.get_va_system_threat_source_details"
  end
  # resource path
  local_var_path = '/api/dashboards/va-system-threat-sources-details'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'orgId'] = org_id
  query_params[:'excludeinherited'] = opts[:'excludeinherited'] if !opts[:'excludeinherited'].nil?
  query_params[:'pageIndex'] = opts[:'page_index'] if !opts[:'page_index'].nil?
  query_params[:'pageSize'] = opts[:'page_size'] if !opts[:'page_size'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetSystemStatusDetails200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['apiKey', 'mockType', 'userId']

  new_options = opts.merge(
    :operation => :"VASystemDashboardsApi.get_va_system_threat_source_details",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: VASystemDashboardsApi#get_va_system_threat_source_details\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end